package
Version:
v0.0.0-...-57b6ef7
Opens a new window with list of versions in this module.
Published: Apr 17, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Generator struct {
}
Generator handles the fuzzing logic
New creates a new generator with the given configuration
Generate produces the specified number of queries
WorkItem represents a unit of work in the generation stack
Source Files
¶
Click to show internal directories.
Click to hide internal directories.